//Class IntKeyList is intended to collect statistics of appearances of integer keys. 

#ifndef IntKeyList_h
#define IntKeyList_h

#include <TClonesArray.h>

using namespace std;

//___________________________________________________________________________________
class IntKeyCntr : public TObject { //Holds number of an integer key occasions
 friend class IntKeyList;           //Assumed to be used by IntKeyList exclusively

 private:
   UInt_t fCount;
   Int_t  fKey;

   UInt_t Inc() {return ++fCount;}

 public:
   IntKeyCntr(Int_t Key = 0) : TObject(), fCount(1), fKey(Key) {}
   virtual ~IntKeyCntr();

   UInt_t GetCount() {return fCount;}
   Int_t  GetKey()   {return fKey;}

   ClassDef(IntKeyCntr,1)
};

//___________________________________________________________________________________
class IntKeyList : public TObject { //Collection of IntKeyCntr's with unique keys
 private:
   UInt_t fTot, fCount;
   TClonesArray *fKeyStat; 

 public:
   IntKeyList() : TObject(), 
                  fTot(0), fCount(0), 
                  fKeyStat(new TClonesArray("IntKeyCntr", 6)) {}

   virtual ~IntKeyList() {delete fKeyStat;}
   
   void AddKey(const Int_t Key);

   UInt_t GetTotalCount()   const {return fTot;}
   UInt_t GetNumberOfKeys() const {return fCount;}

   IntKeyCntr *GetKeyPntr(const UInt_t ind) const {
      return (IntKeyCntr *)fKeyStat->At(ind);
   }

   ClassDef(IntKeyList,1)
};

#endif
